@@ -3,34 +3,25 @@ from cms.models import CMSPlugin
 from django.utils.html import strip_tags
 from django.utils.text import truncate_words
 from django.utils.translation import ugettext_lazy as _
-from djangocms_text_ckeditor.utils import plugin_admin_html_to_tags, \
-    plugin_tags_to_admin_html, plugin_tags_to_id_list, replace_plugin_tags
-from djangocms_text_ckeditor.html import clean_html
+from djangocms_text_ckeditor.utils import plugin_tags_to_id_list, replace_plugin_tags
+from djangocms_text_ckeditor.html import clean_html, extract_images
 
-class TextCKEditor(CMSPlugin):
+
+class Text(CMSPlugin):
     """Abstract Text Plugin Class"""
     body = models.TextField(_("body"))
 
-    def _set_body_admin(self, text):
-        self.body = plugin_admin_html_to_tags(text)
-
-    def _get_body_admin(self):
-        return plugin_tags_to_admin_html(self.body)
-
-    body_for_admin = property(_get_body_admin, _set_body_admin, None,
-                              """
-                              body attribute, but with transformations
-                              applied to allow editing in the
-                              admin. Read/write.
-                              """)
-
     search_fields = ('body',)
 
     def __unicode__(self):
         return u"%s" % (truncate_words(strip_tags(self.body), 3)[:30] + "...")
 
-    def clean(self):
-        self.body = clean_html(self.body, full=False)
+    def save(self, *args, **kwargs):
+        body = self.body
+        body = extract_images(body, self)
+        body = clean_html(body, full=False)
+        self.body = body
+        super(Text, self).save(*args, **kwargs)
 
     def clean_plugins(self):
         ids = plugin_tags_to_id_list(self.body)
@@ -43,11 +34,9 @@ class TextCKEditor(CMSPlugin):
         """
         Fix references to plugins
         """
-
         replace_ids = {}
         for new, old in ziplist:
             replace_ids[old.pk] = new.pk
-
         self.body = replace_plugin_tags(old_instance.get_plugin_instance()[0].body, replace_ids)
         self.save()
 
